# eric7.Plugins.VcsPlugins.vcsMercurial.RebaseExtension.ProjectHelper

Module implementing the rebase extension project helper.

### Global Attributes

None

### Classes

RebaseProjectHelper | Class implementing the rebase extension project helper.

### Functions

None

## RebaseProjectHelper

Class implementing the rebase extension project helper.

### Derived from

HgExtensionProjectHelper

### Class Attributes

None

### Class Methods

None

### Methods

RebaseProjectHelper | Constructor
__hgRebase | Private slot used to rebase changesets to another branch.
__hgRebaseAbort | Private slot used to abort the last rebase session.
__hgRebaseContinue | Private slot used to continue the last rebase session after repair.
initActions | Public method to generate the action objects.
initMenu | Public method to generate the extension menu.
menuTitle | Public method to get the menu title.

### Static Methods

None

#### RebaseProjectHelper (Constructor)

RebaseProjectHelper()

Constructor

#### RebaseProjectHelper.__hgRebase

__hgRebase()

Private slot used to rebase changesets to another branch.

#### RebaseProjectHelper.__hgRebaseAbort

__hgRebaseAbort()

Private slot used to abort the last rebase session.

#### RebaseProjectHelper.__hgRebaseContinue

__hgRebaseContinue()

Private slot used to continue the last rebase session after repair.

#### RebaseProjectHelper.initActions

initActions()

Public method to generate the action objects.

#### RebaseProjectHelper.initMenu

initMenu(mainMenu)

Public method to generate the extension menu.

mainMenu (QMenu)
  reference to the main menu

Return:
  populated menu

Return Type:
  QMenu

#### RebaseProjectHelper.menuTitle

menuTitle()

Public method to get the menu title.

Return:
  title of the menu

Return Type:
  str

Up